emacs-orgmode
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: [Orgmode] [PATCH] Stop generating superfluous clock entries


From: Carsten Dominik
Subject: Re: [Orgmode] [PATCH] Stop generating superfluous clock entries
Date: Fri, 27 Nov 2009 08:09:38 +0100

Thanks, Bernt, good idea!

I have applied a modified version.

- Carsten

On Nov 27, 2009, at 3:21 AM, Bernt Hansen wrote:

Avoid closing the currently clocking entry when clocking in the same task again. Leave the clock entry open until some other task is clocked in.

This allows us to clock in tasks with hooks that are called frequently without
generating lots of short sequential clock entries for the same task.
---
This patch is available at git://git.norang.ca/org-mode.git clock-in

I haven't extensively tested this but it seems to work for for me. I currently
have clock resolution disabled.

lisp/ChangeLog    |    5 +++++
lisp/org-clock.el |   29 ++++++++++++++++++++---------
2 files changed, 25 insertions(+), 9 deletions(-)

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 4acb99c..ecba8f7 100755
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,8 @@
+2009-11-26  Bernt Hansen  <address@hidden>
+
+       * org-clock.el (org-clock-in): Avoid creating superfluous clock
+       entries when clocking in the task that is already running.
+
2009-11-26  Carsten Dominik  <address@hidden>

        * org-footnote.el (org-footnote-normalize): Don't take optional
diff --git a/lisp/org-clock.el b/lisp/org-clock.el
index f598cc3..9bfe53e 100644
--- a/lisp/org-clock.el
+++ b/lisp/org-clock.el
@@ -847,18 +847,29 @@ the clocking selection, associated with the letter `d'."
        (if selected-task
            (setq selected-task (copy-marker selected-task))
          (error "Abort")))
-      (when interrupting
-       ;; We are interrupting the clocking of a different task.
-       ;; Save a marker to this task, so that we can go back.
-       (move-marker org-clock-interrupted-task
-                    (marker-position org-clock-marker)
-                    (marker-buffer org-clock-marker))
-       (org-clock-out t))
-
+
+      (let ((current-hd-marker (make-marker)))
+       ; Find the heading for the current point
+       (move-marker current-hd-marker
+                    (save-excursion
+                      (org-back-to-heading t)
+                      (point))
+                    (buffer-base-buffer))
+       ; Do not clock out if we want to clock in the task
+       ; that is currently clocking
+       (when interrupting
+         (unless (equal current-hd-marker org-clock-hd-marker)
+           ;; We are interrupting the clocking of a different task.
+           ;; Save a marker to this task, so that we can go back.
+           (move-marker org-clock-interrupted-task
+                        (marker-position org-clock-marker)
+                        (marker-buffer org-clock-marker))
+           (org-clock-out t))))
+
      (when (equal select '(16))
        ;; Mark as default clocking task
        (org-clock-mark-default-task))
-
+
      ;; Clock in at which position?
      (setq target-pos
            (if (and (eobp) (not (org-on-heading-p)))
--
1.6.6.rc0.54.gb073b



_______________________________________________
Emacs-orgmode mailing list
Please use `Reply All' to send replies to the list.
address@hidden
http://lists.gnu.org/mailman/listinfo/emacs-orgmode

- Carsten







reply via email to

[Prev in Thread] Current Thread [Next in Thread]